California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 006 - ACA 8 (RESOLUTION CHAPTER 133, STATUTES OF 2024) WILSON. SLAVERY. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1471645 | YES ON PROP 6, END SLAVERY IN CALIFORNIA, SPONSORED BY SOCIAL JUSTICE AND CIVIL RIGHTS ORGANIZATIONS | SUPPORT